@@ -10,25 +10,11 @@ use SNMP_util;
 use SNMP_Session;
 use ISG::ParseConfig;
 use RRDs;
-use Sys::Syslog qw(:DEFAULT setlogsock);
-setlogsock('unix')
-   if grep /^ $^O $/xo, ("linux", "openbsd", "freebsd", "netbsd");
-use File::Basename;
 
 # globale persistent variables for speedy
-use vars qw($cfg $probes $VERSION $havegetaddrinfo);
-$VERSION="1.18";
+use vars qw($cfg $probes $VERSION);
+$VERSION="1.8";
 
-# we want opts everywhere
-my %opt;
-
-BEGIN {
-  $havegetaddrinfo = 0;
-  eval 'use Socket6';
-  $havegetaddrinfo = 1 unless $@;
-}
-
-my $DEFAULTPRIORITY = 'info'; # default syslog priority
 
 sub load_probes ($){
     my $cfg = shift;
@@ -38,7 +24,7 @@ sub load_probes ($){
         die "$@\n" if $@;
 	eval '$prbs{$probe} = probes::'.$probe.'->new( $cfg->{Probes}{${probe}},$cfg );';
         die "$@\n" if $@;
-        die "Failed to load Probe $probe\n" unless defined $prbs{$probe};
+        die "Faild to load Probe $probe\n" unless defined $prbs{$probe};
     }
     return \%prbs;
 };
@@ -94,82 +80,16 @@ sub update_dynaddr ($$){
     } elsif ( -f "$file.snmp") { unlink "$file.snmp" };
         
 }
-sub sendmail ($$$){
-    my $from = shift;
-    my $to = shift;
-    my $body = shift;
-    if ($cfg->{General}{mailhost}){
-	my $smtp = Net::SMTP->new($cfg->{General}{mailhost});
-	$smtp->mail($from);
-	$smtp->to($to);
-	$smtp->data();
-	$smtp->datasend($body);
-	$smtp->dataend();
-	$smtp->quit;
-    } elsif ($cfg->{General}{sendmail} or -f "/usr/lib/sendmail"){
-	open (M, "|-") || exec (($cfg->{General}{sendmail} || "/usr/lib/sendmail"),"-f",$from,$to);
-	print M $body;
-	close M;
-    }
-}
 
-sub init_alerts ($){
-    my $cfg = shift;
-    foreach my $a (keys %{$cfg->{Alerts}}) {
-	my $x = $cfg->{Alerts}{$a};
-        next unless ref $x eq 'HASH';
-	my $sub = " sub { my \$d = shift; my \$y = \$d->{$x->{type}};\n";
-	my @ops = split /\s*,\s*/, $x->{pattern};
-	$x->{length} = scalar @ops;
-        my $i = - $x->{length};
-        $sub .= "return 0 unless $x->{length} <= scalar \@\$y ;\n";
-	for (@ops) {
-	    /^(==|!=|<|>|<=|>=)(\d+(?:\.\d*)?|U|\*)(%?)$/
-		or die "ERROR Alert $a pattern entry '$_' is invalid\n";
-	    my $op = $1;
-	    my $value = $2;
-            my $perc = $3;
-            if ($value eq 'U') {
-		if ($op eq '==') {
-		    $sub .= "return 0 if defined \$y->[$i];\n";
-		} elsif ($op eq '!=') {
-		    $sub .= "return 0 unless defined \$y->[$i];\n";
-		} else {
-		    die "ERROR: invalid operator $op in connection U in Alert $a definition\n";
-		}
-	    } elsif ($value eq '*') {
-		if ($op ne '==') {
-		    die "ERROR: operator $op makes no sense with * in Alert $a definition\n";
-		} # do nothing else ...
-	    } else {
-		if ( $x->{type} eq 'loss') {
-                    die "ERROR: loss should be specified in % (alert $a pattern)\n" unless $perc eq "%";
-		    $value = $value / 100 * $cfg->{Database}{pings};
-		} elsif ( $x->{type} eq 'rtt' ) {
-		    $value /= 1000;
-		} else {
-		    die "ERROR: unknown alert type $x->{type}\n";
-		}
-		$sub .= "return 0 unless defined \$y->[$i] and \$y->[$i] $op $value;\n" ;
-	    }
-	    $i++;
-	}
-        $sub .= "return 1; }";
-	warn "### Compiling\n$sub\n" if $opt{debug};
-	$x->{sub} = eval ( $sub );
-	die "ERROR: compiling alert pattern $a ($x->{pattern}: $@\n" if $@;
-    }
-}
-
-sub init_target_tree ($$$$$$$); # predeclare recursive subs
-sub init_target_tree ($$$$$$$) {
+sub init_target_tree ($$$$$$); # predeclare recursive subs
+sub init_target_tree ($$$$$$) {
     my $cfg = shift;
     my $probes = shift;
     my $probe = shift;
     my $tree = shift;
     my $name = shift;
     my $PROBE_CONF = shift;
-    my $alerts = shift;
+
 
     # inherit probe type from parent
     if (not defined $tree->{probe} or $tree->{probe} eq $probe){
@@ -181,45 +101,24 @@ sub init_target_tree ($$$$$$$) {
 	}
     };
     
-    $tree->{alerts} = $alerts
-	if (not defined $tree->{alerts} and defined $alerts);
-
-    $alerts = $tree->{alerts};
-
-    if ($tree->{alerts}){
-	die "ERROR: no Alerts section\n"
-	    unless exists $cfg->{Alerts};
-	$tree->{alerts} = [ split /\s*,\s*/, $tree->{alerts} ];
-	$tree->{fetchlength} = 0;
- 	foreach $a (@{$tree->{alerts}}) {
-	    die "ERROR: alert $a ($name) is not defined"
-		unless defined $cfg->{Alerts}{$a};
-	    $tree->{fetchlength} = $cfg->{Alerts}{$a}{length}
-		if $tree->{fetchlength} < $cfg->{Alerts}{$a}{length};
-	}
-    };
-
-
     $probe = $tree->{probe};
     $PROBE_CONF = $tree->{PROBE_CONF};
-
+   
     foreach my $prop (keys %{$tree}) {
     	next if $prop eq 'PROBE_CONF';
 	if (ref $tree->{$prop} eq 'HASH'){
 	    if (not -d $name) {
 		mkdir $name, 0755 or die "ERROR: mkdir $name: $!\n";
 	    };
-	    init_target_tree $cfg, $probes, $probe, $tree->{$prop}, "$name/$prop", $PROBE_CONF,$alerts;
+	    init_target_tree $cfg, $probes, $probe, $tree->{$prop}, "$name/$prop", $PROBE_CONF;
 	}
 	if ($prop eq 'host') {
 	    if (not -f $name.".rrd"){
-		RRDs::create
-			($name.".rrd", "--step",$cfg->{Database}{step},
+		RRDs::create ($name.".rrd", "--step",$cfg->{Database}{step},
 			      "DS:uptime:GAUGE:".(2*($cfg->{Database}{step})).":0:U",
 			      "DS:loss:GAUGE:".(2*($cfg->{Database}{step})).":0:".($cfg->{Database}{pings}),
-                               # 180 Seconds  is the max rtt we consider valid ... 
-			      "DS:median:GAUGE:".(2*($cfg->{Database}{step})).":0:180",
-			      (map { "DS:ping${_}:GAUGE:".(2*($cfg->{Database}{step})).":0:180" }
+			      "DS:median:GAUGE:".(2*($cfg->{Database}{step})).":0:10",
+			      (map { "DS:ping${_}:GAUGE:".(2*($cfg->{Database}{step})).":0:10" }
 			                                                  1..($cfg->{Database}{pings})),
 			      (map { "RRA:".(join ":", @{$_}) } @{$cfg->{Database}{_table}} ));
 		my $ERROR = RRDs::error();
@@ -292,8 +191,23 @@ sub enable_dynamic($$$$){
 
 	    my $mail;
             print STDERR "Sending smoke-agent for $usepath to $email ... ";
-	    sendmail $cfg->{General}{contact},$email,$body;
-	    print STDERR "DONE\n";
+            if ($cfg->{General}{mailhost}){
+                 eval "require Net::SMTP";
+                 unless ($@){
+                     my $smtp = Net::SMTP->new($cfg->{General}{mailhost});
+                     $smtp->mail($cfg->{General}{contact});
+                     $smtp->to($email);
+                     $smtp->data();
+                     $smtp->datasend($body);
+                     $smtp->dataend();
+                     $smtp->quit;
+                 }
+             } elsif ($cfg->{General}{sendmail} or -f "/usr/lib/sendmail"){
+        	open (M, "|-") || exec (($cfg->{General}{sendmail} || "/usr/lib/sendmail"),"-t");
+          	print M $body;
+                close M;
+             }
+             print STDERR "DONE\n";
         }
     }
     foreach my $prop ( keys %{$tree}) {
@@ -407,16 +321,13 @@ sub get_overview ($$$$){
 	   '--imgformat','PNG',
            '--lower-limit','0',
 	   "DEF:median=${rrd}:median:AVERAGE",
-	   "DEF:loss=${rrd}:loss:AVERAGE",
-           "CDEF:ploss=loss,$cfg->{Database}{pings},/,100,*",
            "CDEF:dm=median,0,$max,LIMIT",
-           "CDEF:dm2=median,1.5,*,0,$max,LIMIT",
+           "CDEF:dm2=median,1.5,*",
 	   "LINE1:dm2", # this is for kicking things down a bit
-	   "LINE1:dm#$medc:median RTT avg\\:    ",
-           "GPRINT:median:AVERAGE: %0.2lf %ss     ",
-           "GPRINT:median:LAST:     latest RTT\\: %0.2lf %ss     ",
-   	   "GPRINT:ploss:AVERAGE:    avg pkg loss\\: %.2lf %% ",
-	   "COMMENT:         $date\\j");
+	   "LINE1:dm#$medc:median RTT",
+           "GPRINT:median:AVERAGE:     avg median RTT\\: %0.2lf %ss",
+              "GPRINT:median:LAST:     latest RTT\\: %0.2lf %ss          ",
+	   "COMMENT:           $date\\j");
 	my $ERROR = RRDs::error();
 	$page .= "<div>";
         if (defined $ERROR) {
@@ -469,12 +380,11 @@ sub findmax ($$) {
                 $maxmedian{$x} = $max * 1.5;
         }
         # make it a nice clean number
-        $maxmedian{$x} =~ s/^([0-9.]*)([1-9]).*/$1$2/;
+        $maxmedian{$x} =~ s/^([0.]*)([1-9]).*/$1$2/;
         $maxmedian{$x} += ( ${1}."1" + 0.0 ) ;
 
         $maxmedian{$x} = $cfg->{Presentation}{detail}{max_rtt} 
-                if $cfg->{Presentation}{detail}{max_rtt} and
-		    $maxmedian{$x} > $cfg->{Presentation}{detail}{max_rtt}
+                if $cfg->{Presentation}{detail}{max_rtt} && $maxmedian{$x} > $cfg->{Presentation}{detail}{max_rtt}        
      };
      return \%maxmedian;    
 }
@@ -552,11 +462,10 @@ sub get_detail ($$$$){
 	my ($desc,$start) = @{$_};
 	$start = exp2seconds($start);
     do {
-	@median = ("DEF:median=${rrd}:median:AVERAGE",
+	@median = ('COMMENT:Median Ping RTT  (', 
+		   "DEF:median=${rrd}:median:AVERAGE",
 		   "DEF:loss=${rrd}:loss:AVERAGE",
-                   "CDEF:ploss=loss,$cfg->{Database}{pings},/,100,*",
-           	   "GPRINT:median:AVERAGE:Median Ping RTT (avg %.1lf %ss) (",
-                   "LINE1:median#202020"
+		   "LINE1:median#202020"
         	   );
 	my $p = $cfg->{Database}{pings}; 
 
@@ -580,18 +489,18 @@ sub get_detail ($$$$){
         my $last = -1;
         my $swidth = $max->{$start} / $cfg->{Presentation}{detail}{height};
 	foreach my $loss (sort {$a <=> $b} keys %lc){
-            my $lvar = $loss; $lvar =~ s/\./d/g ;
 	    push @median, 
 	    (
-	     "CDEF:me$lvar=loss,$last,GT,loss,$loss,LE,*,1,UNKN,IF,median,*",
-	     "CDEF:meL$lvar=me$lvar,$swidth,-",
-	     "CDEF:meH$lvar=me$lvar,0,*,$swidth,2,*,+",             
-	     "AREA:meL$lvar",
-	     "STACK:meH$lvar$lc{$loss}[1]:$lc{$loss}[0]"
+	     "CDEF:me$loss=loss,$last,GT,loss,$loss,LE,*,1,UNKN,IF,median,*",
+	     "CDEF:meL$loss=me$loss,$swidth,-",
+	     "CDEF:meH$loss=me$loss,0,*,$swidth,2,*,+",             
+	     "AREA:meL$loss",
+	     "STACK:meH$loss$lc{$loss}[1]:$lc{$loss}[0]"
 	     );
              $last = $loss;
 	}
-	push @median, ( "GPRINT:ploss:AVERAGE:avg pkg loss\\: %.2lf %%\\l" );
+	push @median, ( 'GPRINT:median:AVERAGE:loss )  avg\: %.1lf %ss\l',
+		       );
 #	map {print "$_<br/>"} @median;
     };
         # if we have uptime draw a colorful background or the graph showing the uptime
@@ -604,7 +513,7 @@ sub get_detail ($$$$){
        		           'GPRINT:duptime:LAST: %0.1lf days  (');
         	my %upt;
                 if ( defined $cfg->{Presentation}{detail}{uptime_colors}{_table} ) {
-                    for (@{$cfg->{Presentation}{detail}{uptime_colors}{_table}}) {
+                    for (@{$cfg->{Presentation}{detail}{_table}}) {
                         my ($num,$col,$txt) = @{$_};
                         $upt{$num} = [ $txt, "#".$col];
                     }
@@ -638,8 +547,7 @@ sub get_detail ($$$$){
 #	map {print "$_<br/>"} @upargs;
     };
         my @log = ();
-        push @log, "--logarithmic" if  $cfg->{Presentation}{detail}{logarithmic} and
-	    $cfg->{Presentation}{detail}{logarithmic} eq 'yes';
+        push @log, "--logarithmic" if  $cfg->{Presentation}{detail}{logarithmic} and $cfg->{Presentation}{detail}{logarithmic} eq 'yes';
 
         my @lazy =();
         @lazy = ('--lazy') if $lasthight{$start} and $lasthight{$start} == $max->{$start};
@@ -653,7 +561,7 @@ sub get_detail ($$$$){
            '--rigid',
            '--upper-limit', $max->{$start},
 	   @log,
-	   '--lower-limit',(@log ? ($max->{$start} > 0.01) ? '0.001' : '0.0001' : '0'),
+	   '--lower-limit',(@log ? '0.001' : '0'),
 	   '--vertical-label',"Seconds",
 	   '--imgformat','PNG',
 	   '--color', 'SHADEA#ffffff',
@@ -722,13 +630,7 @@ sub run_probes($) {
         $probes->{$probe}->ping();
     }
 }
-# report probe status
-sub report_probes($) {
-    my $probes = shift;
-    foreach my $probe (keys %{$probes}){
-        $probes->{$probe}->report();
-    }
-}
+
 
 sub update_rrds($$$$$);
 sub update_rrds($$$$$) {
@@ -745,73 +647,11 @@ sub update_rrds($$$$$) {
         } 
         if ($prop eq 'host') {
             RRDs::update ( $name.".rrd", 
-        	   '--template',(join ":", "uptime", "loss", "median",
-				 map { "ping${_}" } 1..($cfg->{Database}{pings})),
+        	   '--template',(join ":", "uptime", "loss", "median", map { "ping${_}" } 1..($cfg->{Database}{pings})),
 	           "N:".$probes->{$probe}->rrdupdate_string($tree)
 		 );     
             my $ERROR = RRDs::error();
 	    die "ERROR: $ERROR\n" if $ERROR;
-	    # check alerts
-# disabled
-	    if ( $tree->{alerts}) {
-                $tree->{stack} = {loss=>[],rtt=>[]} unless defined $tree->{stack};
-		my $x = $tree->{stack};
-		my ($loss,$rtt) = 
-		    (split /:/, $probes->{$probe}->rrdupdate_string($tree))[1,2];
-		$loss = undef if $loss eq 'U';
-		$rtt = undef if $rtt eq 'U';
-		push @{$x->{loss}}, $loss;
-		push @{$x->{rtt}}, $rtt;
-		if (scalar @{$x->{loss}} > $tree->{fetchlength}){
-		    shift @{$x->{loss}};
-		    shift @{$x->{rtt}};
-		}
-		for (@{$tree->{alerts}}) {
-		    if ( &{$cfg->{Alerts}{$_}{sub}}($x) ){
-			# we got a match
-			my $from;
-                        my $line = "$name/$prop";
-                        my $base = $cfg->{General}{datadir};
-                        $line =~ s|^$base/||;
-                        $line =~ s|/host$||;
-                        $line =~ s|/|.|g;
-                        my $urlline = $line;
-                        $urlline =  $cfg->{General}{cgiurl}."?target=".$line;
-                        my $loss = "loss: ".join ", ",map {sprintf "%.0f %%", ( $_ || 0 ) / $cfg->{Database}{pings} * 100} @{$x->{loss}};
-                        my $rtt = "rtt: ".join ", ",map {$_ ? (sprintf "%.0f ms", $_*1000):"U" } @{$x->{rtt}}; 
-                        my $stamp = scalar localtime time;
-			if ($cfg->{Alerts}{to} =~ /^\|(.+)/) {
-			    system $1,$_,$line,$loss,$rtt,$tree->{host};	    			    
-			} else {
-			    sendmail $cfg->{Alerts}{from},$cfg->{Alerts}{to}, <<ALERT;
-To: $cfg->{Alerts}{to}
-From: $cfg->{Alerts}{from}
-Subject: [SmokeAlert] $_ on $line
-
-$stamp
-
-Got a match for alert "$_" for $urlline
-
-Pattern
--------
-$cfg->{Alerts}{$_}{pattern}
-
-Data
-----
-$loss
-$rtt
-
-Comment
--------
-$cfg->{Alerts}{$_}{comment}
-
-
-
-ALERT
-			}
-		    }
-		}
-	    }
 	}
     }
 }
@@ -821,7 +661,7 @@ sub get_parser () {
     my $TARGET = 
       {
        _sections => [ ( "PROBE_CONF", "/$KEY_RE/" ) ],
-       _vars     => [ qw (probe menu title alerts note email host remark) ],
+       _vars     => [ qw (probe menu title note email host remark) ],
        _mandatory=> [ qw (menu title) ],
        _doc => <<DOC,
 Each target section can contain information about a host to monitor as
@@ -829,11 +669,6 @@ well as further target sections. Most variables have already been
 described above. The expression above defines legal names for target
 sections.
 DOC
-       alerts    => {
-		     _doc => 'Comma separated list of alert names',
-		     _re => '[^\s,]+(,[^\s,]+)*',
-		     _re_error => 'Comma separated list of alert names',
-		    },
        host      => 
        {
 	_doc => <<DOC,
@@ -854,20 +689,10 @@ DOC
 	_sub => sub {
 	    for ( shift ) {
 		m|^DYNAMIC| && return undef;
-		/^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/ && return undef;
-		/^[0-9a-f]{0,4}(\:[0-9a-f]{0,4}){0,6}\:[0-9a-f]{0,4}$/i && return undef;
-		if ($havegetaddrinfo) {
-		  my @ai;
-		  @ai = getaddrinfo( $_, "" );
-		  if (scalar(@ai) <= 5) {
+		/^\d+\.\d+\.\d+\.\d+$/ && return undef;
 # do not bomb, as this could be temporary
-		    warn "WARNING: Hostname '$_' does currently not resolve to an IP address (@ai)\n";
-		  }
-		} else {
-# do not bomb, as this could be temporary
-		  warn "WARNING: Hostname '$_' does currently not resolve to an IP address\n"
-		    unless gethostbyname( $_ );
-		}
+		warn "WARNING: Hostname '$_' does currently not resolve to an IP address\n"
+		  unless gethostbyname( $_ );
                 return undef;
 	    }
 	    return undef;
@@ -927,7 +752,7 @@ DOC
     my $parser = ISG::ParseConfig->new 
       (
        {
-	_sections  => [ qw(General Database Presentation Probes Alerts Targets) ],
+	_sections  => [ qw(General Database Presentation Probes Targets) ],
 	_mandatory => [ qw(General Database Presentation Probes Targets) ],
 	General    => 
 	{
@@ -936,8 +761,7 @@ General configuration values valid for the whole SmokePing setup.
 DOC
 	 _vars =>
 	 [ qw(owner imgcache imgurl datadir piddir sendmail
-              smokemail cgiurl mailhost contact 
-	      syslogfacility syslogpriority) ],
+              smokemail cgiurl mailhost contact) ],
 	 _mandatory =>
 	 [ qw(owner imgcache imgurl datadir piddir
               smokemail cgiurl contact) ],
@@ -970,7 +794,6 @@ DOC
 Instead of using sendmail, you can specify the name of an smtp server 
 and use perl's Net::SMTP module to send mail to DYNAMIC host owners (see below).
 DOC
-          _sub => sub { require Net::SMTP ||return "ERROR: loading Net::SMTP"; return undef; }
 	 },
 
 	 contact  => 
@@ -1024,27 +847,8 @@ DOC
 Complete URL path of the SmokePing.cgi
 DOC
 	  
-	 },
-	 syslogfacility	=>
-	 {
-	  _re => '\w+',
-	  _re_error => 
-	  "syslogfacility must be alphanumeric",
-	  _doc => <<DOC,
-The syslog facility to use, eg. local0...local7. 
-Note: syslog logging is only used if you specify this.
-DOC
-	 },
-	 syslogpriority	=>
-	 {
-	  _re => '\w+',
-	  _re_error => 
-	  "syslogpriority must be alphanumeric",
-	  _doc => <<DOC,
-The syslog priority to use, eg. debug, notice or info. 
-Default is $DEFAULTPRIORITY.
-DOC
-	 },
+	 }
+	 
 	},
 	Database => 
 	{ 
@@ -1335,16 +1139,15 @@ DOC
 	uptime_colors => {
 	  _table     => { _columns => 3,
 			  _doc => <<DOC,
-When monitoring a host with DYNAMIC addressing, SmokePing will keep
-track of how long the machine is able to keep the same IP
-address. This time is plotted as a color in the graphs
-background. SmokePing comes with a reasonable default setting, but you
-may choose to disagree. The table below lets you specify your own
-coloring
+When monitoring a host with DYNAMIC addressing, SmokePing will keep track of how long
+the machine is able to keep the same IP address. This time is plotted as a color
+in the graphs background. SmokePing comes with a reasonable default setting,
+but you may choose to disagree. The table below
+lets you specify your own coloring
 
 Example:
 
- # Uptime Color            Legend
+ Uptime Color     Legend
  3600    00ff00   "<1h"
  86400   0000ff   "<1d"
  604800  ff0000   "<1w"
@@ -1397,93 +1200,13 @@ DOC
 variables it wants to accept. So this expression here just defines legal variable names.'}
 				   }
 		  },
-	Alerts  => {
-		    _doc => <<DOC,
-The Alert section lets you setup loss and RTT detectors. After each
-round of polling, SmokePing will examine its data and determine which
-detectors match. Detectors are enabled per target and get inherited by
-the targets children.
 
-Detectors are not just simple thresholds which go off at first sight
-of a problem. They are configurable to detect special loss or RTT
-patterns. They let you look at a number of past readings to make a
-more educated decision on what kind of alert should be sent, or if an
-alert should be sent at all.
-
-The patterns are numbers prefixed with an operator indicating the type
-of comparison required for a match.
-
-The following RTT pattern detects if a targets RTT goes from constanty
-below 10ms to constantly 100ms and more:
-
- old ------------------------------> new
- <10,<10,<10,<10,<10,>10,>100,>100,>100
-
-Loss patterns work in a similar way, only that the
-loss is defined in percentage off the total of packets total sent packets.
-
- old ------------------------------> new
- ==0%,==0%,==0%,==0%,>20%,>20%,>=20%
-
-Apart from normal numbers, patterns can also contain the values B<*>
-which is true for all values regardless of the operator. And B<U>
-which is true for B<unknown> data together with the B<==> and B<=!> operators.
-
-A complete example
-
- *** Alerts ***
- to = admin\@company.xy
- from = smokealert\@company.xy
-
- +lossdetect
- type = loss
- # in percent
- pattern = ==0%,==0%,==0%,==0%,>20%,>20%,>20%
- comment = suddenly there is packet loss
-
- +rttdetect
- type = rtt
- # in milli seconds
- pattern = <10,<10,<10,<10,<10,<100,>100,>100,>100
- comment = routing mesed up again ?
-
-DOC
-
-	     _sections => [ '/[^\s,]+/' ],
-	     _vars => [ qw(to from) ],
-	     _mandatory => [ qw(to from)],
-	     to => { doc => 'Either an email address to send alerts to, or the name of a
-program to execute when an alert matches. To call a program, the first character of the B<to>
-value must be a pipe symbol "|". The program will the be called whenever an alert matches,
-using the following 5 arguments: B<name-of-alert>, B<target>, B<loss-pattern>, B<rtt-pattern>, B<hostname>.',
-			_re => '(\|.+|.+@\S+)',
-			_re_error => 'put an email address or the name of a program here',
-		      },
-	     from => { doc => 'whom should alerts appear to be coming from ?',
-		       _re => '.+@\S+',
-		       _re_error => 'put an email address here',
-		      },
-	     '/[^\s,]+/' => {
-		  _vars => [ qw(type pattern comment) ],
-		  _mandatory => [ qw(type pattern comment) ],
-		  type => {
-		     _doc => 'Currently the pattern types B<rtt> and B<loss> are known',
-		     _re => '(rtt|loss)',
-                     _re_error => 'Use loss or rtt'
-			  },
-   	 	  pattern => {
- 		     _doc => "a comma separated list of comparison operators and numbers. rtt patterns are in milli seconds, loss patterns are in percent",
-		     _re => '(==|<|<=|>|>=|!=)(\d+(?:\.\d*)?|U|\*)%?(,(?:==|<|<=|>|>=|!=)(?:\d+(?:\.\d*)?|U|\*)%?)*',
- 		     _re_error => 'Could not parse pattern',
-		             },
-		  },
-        },
        Targets => {_doc        => <<DOC,
 The Target Section defines the actual work of SmokePing. It contains a hierarchical list
 of hosts which mark the endpoints of the network connections the system should monitor.
 Each section can contain one host as well as other sections.
 DOC
-		   _vars       => [ qw(probe menu title remark alerts) ],
+		   _vars       => [ qw(probe menu title remark) ],
 		   _mandatory  => [ qw(probe menu title) ],
 		   _sections   => [ ( "PROBE_CONF", "/$KEY_RE/" ) ],
 		   probe => { _doc => <<DOC },
@@ -1493,13 +1216,6 @@ DOC
 		   PROBE_CONF => $PROBEVARS,
 		   menu => { _doc => <<DOC },
 Menu entry for this section
-DOC
-                   alerts => { _doc => <<DOC },
-A comma separated list of alerts to check for this target. The alerts have
-to be setup in the Alerts section. Alerts are inherited by child nodes. Use
-anempty alerts definition to remove inherited alerts from the current target
-and ist childern.
-
 DOC
 		   title => { _doc => <<DOC },
 Title of the page when it is displayed.
@@ -1510,8 +1226,7 @@ DOC
 
 		   "/$KEY_RE/" => $TARGET
 		  }
-            
-      }
+        }
     );
     return $parser;
 }
@@ -1546,11 +1261,11 @@ sub demonize_me ($) {
         if (-f $pidfile ) {
             open PIDFILE, "<$pidfile";
             <PIDFILE> =~ /(\d+)/;
-            close PIDFILE;
             my $pid = $1;
             die "ERROR: I Quit! Another copy of $0 ($pid) seems to be running.\n".
               "       Check $pidfile\n"
                 if kill 0, $pid;
+            close PIDFILE;
         }
     }
     print "Daemonizing $0 ...\n";
@@ -1569,60 +1284,10 @@ sub demonize_me ($) {
         open STDOUT,'>/dev/null' or die "ERROR: Redirecting STDOUT to /dev/null: $!";
         open STDIN, '</dev/null' or die "ERROR: Redirecting STDIN from /dev/null: $!";
         open STDERR, '</dev/null' or die "ERROR: Redirecting STDERR from /dev/null: $!";
+        
     }
 }
 
-{
-	my $use_syslog = 0;
-	my $use_cgilog = 0;
-	my $use_debuglog = 0;
-
-	my $syslog_facility;
-	my $syslog_priority = $DEFAULTPRIORITY;
-	
-	sub initialize_debuglog {
-		$use_debuglog = 1;
-	}
-
-	sub initialize_cgilog {
-		$use_cgilog = 1;
-	}
-	
-	sub initialize_syslog {
-		my $fac = shift;
-		my $pri = shift;
-		$use_syslog = 1;
-		die("missing facility?") unless defined $fac;
-		$syslog_facility = $fac if defined $fac;
-		$syslog_priority = $pri if defined $pri;
-		print "Note: logging to syslog as $syslog_facility/$syslog_priority.\n";
-		openlog(basename($0), 'pid', $syslog_facility);
-	}
-
-	sub do_syslog {
-		syslog("$syslog_facility|$syslog_priority", @_);
-	}
-
-	sub do_cgilog {
-		print "<p>" , @_, "</p>\n";
-		print STDERR @_; # for the webserver log
-	}
-
-	sub do_debuglog {
-		print STDERR @_;
-	}
-
-	sub do_log {
-		my $string = join(" ", @_);
-		chomp $string; 
-		$string .= "\n";
-		do_syslog($string) if $use_syslog;
-		do_cgilog($string) if $use_cgilog;
-		do_debuglog($string) if $use_debuglog;
-	}
-
-}
-
 ###########################################################################
 # The Main Program 
 ###########################################################################
@@ -1644,8 +1309,7 @@ sub load_cfg ($) {
         $probes = undef;
 	$probes = load_probes $cfg;
 	$cfg->{__probes} = $probes;
-	init_alerts $cfg if $cfg->{Alerts};
-      	init_target_tree $cfg, $probes, $cfg->{Targets}{probe}, $cfg->{Targets}, $cfg->{General}{datadir}, $cfg->{Targets}{PROBE_CONF},$cfg->{Targets}{alerts}; 
+      	init_target_tree $cfg, $probes, $cfg->{Targets}{probe}, $cfg->{Targets}, $cfg->{General}{datadir}, $cfg->{Targets}{PROBE_CONF}; 
     }    
 }
 
@@ -1732,7 +1396,6 @@ sub cgi ($) {
         $SIG{__WARN__} = sub { print "<pre>".(shift)."</pre>"; };
         $SIG{__DIE__} = sub { print "<pre>".(shift)."</pre>"; exit 1 }
     };
-    initialize_cgilog();
     if ($q->param(-name=>'secret') && $q->param(-name=>'target') ) {
 	update_dynaddr $cfg,$q;
     } else {
@@ -1740,29 +1403,19 @@ sub cgi ($) {
     }
 }
 
-    
 sub main ($) {
     umask 022;
     my $cfgfile = shift;
-    GetOptions(\%opt, 'version', 'email', ,'man','help',
-                      'makepod','debug','restart', 'nodemon|nodaemon') or pod2usage(2);
-    if($opt{version})  { print "$RCS_VERSION\n"; exit(0) };
-    if($opt{man})      {  pod2usage(-verbose => 2); exit 0 };
-    if($opt{help})     {  pod2usage(-verbose => 1); exit 0 };
     load_cfg $cfgfile;
-    if($opt{makepod})  { makepod $cfg; exit 0}; 
+    my %opt;
+    GetOptions(\%opt, 'version', 'email', 
+                      'makepod','debug','restart', 'nodemon|nodaemon');
+    if($opt{version})  { print "$RCS_VERSION\n"; exit(0) };
     if($opt{email})    { enable_dynamic $cfg, $cfg->{Targets},"",""; exit 0 };
-    if($opt{restart})  { kill_smoke $cfg->{General}{piddir}."/smokeping.pid";};
-    unless ($opt{debug} or $opt{nodemon}) {
-    	if (defined $cfg->{General}{syslogfacility}) {
-		initialize_syslog($cfg->{General}{syslogfacility}, 
-				  $cfg->{General}{syslogpriority});
-	}
-    	demonize_me $cfg->{General}{piddir}."/smokeping.pid";
-    }
-    initialize_debuglog if $opt{debug};
-    do_log("Launched successfully");
-    report_probes($probes);
+    if($opt{makepod})  { makepod $cfg; }; 
+    if($opt{restart})  { kill_smoke $cfg->{General}{piddir}."/smokeping.pid"; };
+    demonize_me $cfg->{General}{piddir}."/smokeping.pid"
+      unless $opt{debug} or $opt{nodemon};
     while (1) {
     	if ($opt{debug}) {
 		map { $probes->{$_}->debug(1) if $probes->{$_}->can('debug') } 
@@ -1904,8 +1557,7 @@ Almost all SmokePing functionality sitts in this Module.
 The programs B<smokeping> and B<smokeping.cgi> are merily
 figure heads allowing to hardcode some pathnames.
 
-If you feel like documenting what is happening within this library you are
-most welcome todo so.
+If you feel like documenting what is happening within this library you are most welcome todo so.
 
 =head1 COPYRIGHT
 
